package com.xkrs.model.entity;

import javax.persistence.*;
import java.math.BigDecimal;

/**
 * @Author: XinYi Song
 * @Date: 2021/12/15 13:41
 */
@Entity
@Table(name="product")
public class ProductEntity {
    /**
     * 指定主键，建立自增序列，主键值取自序列
     */
    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "product_seq_gen")
    @SequenceGenerator(name = "product_seq_gen", sequenceName = "product_id_seq")
    private Integer id;

    /**
     * 商品名称
     */
    private String productName;

    /**
     * 商品描述
     */
    private String productDescription;

    /**
     * 商品分类
     */
    private Integer productCategories;

    /**
     * 商品价格
     */
    private BigDecimal productPrice;

    /**
     * 商品上架状态（默认0 待审核，1审核通过，2审核不通过）
     */
    @Column(length = 32, columnDefinition = "varchar(32)")
    private String shelfType;

    /**
     * 商家id
     */
    private Integer businessId;

    /**
     * 商品上架的时间
     */
    @Column(length = 65, columnDefinition = "varchar(65)")
    private String productTime;

    public ProductEntity() {
    }

    public ProductEntity(Integer id, String productName, String productDescription, Integer productCategories, BigDecimal productPrice, String shelfType, Integer businessId, String productTime) {
        this.id = id;
        this.productName = productName;
        this.productDescription = productDescription;
        this.productCategories = productCategories;
        this.productPrice = productPrice;
        this.shelfType = shelfType;
        this.businessId = businessId;
        this.productTime = productTime;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getProductDescription() {
        return productDescription;
    }

    public void setProductDescription(String productDescription) {
        this.productDescription = productDescription;
    }

    public Integer getProductCategories() {
        return productCategories;
    }

    public void setProductCategories(Integer productCategories) {
        this.productCategories = productCategories;
    }

    public BigDecimal getProductPrice() {
        return productPrice;
    }

    public void setProductPrice(BigDecimal productPrice) {
        this.productPrice = productPrice;
    }

    public String getShelfType() {
        return shelfType;
    }

    public void setShelfType(String shelfType) {
        this.shelfType = shelfType;
    }

    public Integer getBusinessId() {
        return businessId;
    }

    public void setBusinessId(Integer businessId) {
        this.businessId = businessId;
    }

    public String getProductTime() {
        return productTime;
    }

    public void setProductTime(String productTime) {
        this.productTime = productTime;
    }

    @Override
    public String toString() {
        return "ProductEntity{" +
                "id=" + id +
                ", productName='" + productName + '\'' +
                ", productDescription='" + productDescription + '\'' +
                ", productCategories=" + productCategories +
                ", productPrice=" + productPrice +
                ", shelfType='" + shelfType + '\'' +
                ", businessId=" + businessId +
                ", productTime='" + productTime + '\'' +
                '}';
    }
}
